@@ -260,6 +260,7 @@ has 'primary_columns' => ( is => 'ro', isa => 'ArrayRef[Str]', lazy => 1, defaul
   # If the db has no primary columns, then we have to use ALL the columns:
   unless ($self->ResultSource->primary_columns > 0) {
     my $class = $self->ResultSource->schema->class($self->ResultSource->source_name);
+    local $SIG{__WARN__} = sub {}; # GitHub Issue #167 - TODO/FIXME
     $class->set_primary_key( $self->ResultSource->columns );
     $self->ResultSource->set_primary_key( $self->ResultSource->columns );
   }
@@ -768,6 +769,21 @@ sub rs_all {
   my ($self, $Rs) = @_;
   my $want = wantarray;
   
+  ## ---------
+  ## Experimental override to force all joins to be LEFT joins, since in the
+  ## context of the grid, it is never helpful to inner join which can cause
+  ## rows to not show up when the foreign key isn't found, which is never what
+  ## we want to happen - TODO: add test cases for this
+  no warnings 'redefine';
+  my $orig_resolve_join = \&DBIx::Class::ResultSource::_resolve_join;
+  local *DBIx::Class::ResultSource::_resolve_join = sub {
+    my ($self, $join, $alias, $seen, $jpath, $parent_force_left) = @_;
+    return $orig_resolve_join->($self, $join, $alias, $seen, $jpath, 1)
+  };
+  # for more info, see the thread/convo on github: 
+  #  https://github.com/vanstyn/RapidApp/commit/cab4a6732
+  ## ---------
+
   # ----- GitHub Issue #165
   # NEW: extract the nested select refs from the special ''/-as structure for
   # the query, throwing away the outer layer and the -as. This is being done 
