@@ -1,4 +1,4 @@
-#!/usr/bin/perl -w
+#!/usr/bin/env perl
 
 use strict;
 use Getopt::Long;
@@ -91,6 +91,15 @@ rapidapp.pl - Bootstrap a RapidApp/Catalyst application
    rapidapp.pl --helpers RapidDbic MyApp -- --from-sqlite-ddl my-schema.sql
    rapidapp.pl --helpers RapidDbic MyApp -- --blank-ddl
 
+   rapidapp.pl --helpers RapidDbic MyApp -- \
+     --dsn 'dbi:Pg:dbname=foo;host=localhost;port=5432',larry,secretpw \
+     --loader-option db_schema='%' --loader-option generate_pod=1 \
+     --connect-option quote_names=0
+
+   rapidapp.pl --helpers RapidDbic MyApp -- --dsn \
+     'dbi:ODBC:Driver=TDS;TDS_Version=7.0;Server=10.1.2.3;Port=1433;Database=Blah',sa,topsecret \
+
+
 =head1 DESCRIPTION
 
 The C<rapidapp.pl> script bootstraps a RapidApp/Catalyst application, creating a
